
Boiling in plate and frame exchangers (ht.boiling_plate)
========================================================

.. automodule:: ht.boiling_plate
    :members:
    :undoc-members:
    :show-inheritance:
